from setuptools import setup, find_packages

setup(
    name="hello-world-app",
    version="0.1",
    packages=find_packages(),
    entry_points={
        "console_scripts": [
            "hello-world-app = app:hello_world",
        ]
    },
)
